@@ -75,7 +75,7 @@ def integrate_dos(G, mu=0, T=300, nzp=100, R=1e10):
     a_p = mu + 1j*zp/beta
 
     eta = G.eta
-    G.eta = complex(0.)
+    G.eta = 0.
 
     R = 1e10
     mu_0 = 1j*R*G.apply_retarded(1j*R, G.S).trace()
@@ -103,7 +103,7 @@ def _(G, mu=0, T=300, nzp=100, R=1e10):
     a_p = mu + 1j*zp/beta
 
     eta = G.eta
-    G.eta = complex(0.)
+    G.eta = 0.
 
     R = 1e10
     mu_0 = 1j*R * G.retarded(1j*R).dottrace(G.S)
@@ -131,7 +131,7 @@ def integrate_pdos(G, mu=0, T=300, nzp=100, R=1e10):
     a_p = mu + 1j*zp/beta
 
     eta = G.eta
-    G.eta = complex(0.)
+    G.eta = 0.
 
     R = 1e10
     mu_0 = 1j*R*G.apply_retarded(1j*R, G.S).diagonal()
@@ -159,7 +159,7 @@ def _(G, mu=0, T=300, nzp=100, R=1e10):
     a_p = mu + 1j*zp/beta
 
     eta = G.eta
-    G.eta = complex(0.)
+    G.eta = 0.
 
     R = 1e10
     mu_0 = 1j*R * G.retarded(1j*R).dotdiag(G.S)
