@@ -158,13 +158,14 @@ def build_partial_kpts(size, offset=(0.,0.,0.), direction='x'):
     return kpts_p, kpts_t
 
 
-def fourier_sum(A, kpts, R, out=None):
+def fourier_sum(A, kpts, R, out=None, inverse=False):
     '''K-space Fourier sum.
     
     Args:
         A : (np.ndarray) matrices in k-space.
-        kpts : (1D or 2D) k-points at which A's have been evaluated.
-        R : (1D or 2D) lattice vectors at which A's will be transformed.
+        kpts : (1D or 2D) k-points at which A's have been (will be) evaluated.
+        R : (1D or 2D) lattice vectors at which A's will be (have been) evaluated.
+        inverse : compute inverse fourier transform
     '''
     # np.asarray avoids copy
     kpts = np.asarray(kpts)
@@ -183,7 +184,10 @@ def fourier_sum(A, kpts, R, out=None):
 
     out.shape = (out.shape[0], -1)
     A.shape = (A.shape[0], -1)
-    phase  = np.exp(2.j * np.pi * np.dot(R, kpts.T)) / kpts.shape[0]
+    if inverse:
+        phase  = np.exp(-2.j * np.pi * np.dot(kpts, R.T))
+    else:
+        phase  = np.exp(2.j * np.pi * np.dot(R, kpts.T)) / kpts.shape[0]
     np.sum(phase[...,None] * A[None,...], axis=1, out=out)
     A.shape = (kpts.shape[0],) + shape[1:]
     out.shape = shape
