@@ -1,3 +1,4 @@
+from qtpyt.basis import argsort
 import numpy as np
 from scipy.spatial.distance import cdist
 
@@ -31,12 +32,13 @@ def remove_pbc(basis, A_kMM, direction='x', eps=-1e-3):
 
 def oder_indices(basis, N, order='xyz', positions=None):
     repeated = basis.repeat(N)
+    # Get map from repeated to target order.
     if positions is not None:
-        idx = cdist(repeated.centers, positions).argmin(1) 
-        return repeated.get_index(idx)
+        r2o = cdist(repeated.atoms.positions, positions).argmin(0) 
     else:
-        idx = repeated.argsort(order)
-        return repeated.get_indices(idx)
+        positions = repeated.atoms.positions.round(3)
+        r2o = argsort(positions, order)
+    return repeated.get_indices(r2o)
 
 
 def prepare_leads_matrices(basis, H_kMM, S_kMM, size, offset=(0.,0.,0.), direction='x'):
